| {$ 'Power on' | translate $} {$ 'Power off' | translate $} {$ 'Maintenance on' | translate $} {$ 'Maintenance off' | translate $}
--- | ---
| Node Name | Instance ID | Power State | Provisioning State | Maintenance | Ports | Driver | Actions
| {$ node.name || node.uuid $} | {$ node.instance_uuid $} {$ 'No Instance' | translate $} | {$ node.power_state $} | {$ node.provision_state $} | {$ node.maintenance $} | {$ node.ports.length $} | {$ node.driver $} | {$ 'Power on' | translate $} {$ 'Power off' | translate $} {$ 'Maintenance on' | translate $} {$ 'Maintenance off' | translate $}